@@ -1,5 +1,6 @@
 from pyps4_2ndscreen.ddp import get_status
-from pyremoteplay.const import RESOLUTION_PRESETS
+from pyremoteplay.av import AVReceiver
+from pyremoteplay.const import RESOLUTION_PRESETS, Quality
 from pyremoteplay.oauth import LOGIN_URL, get_user_account
 from pyremoteplay.register import register
 from pyremoteplay.util import (add_profile, add_regist_data, get_mapping,
@@ -323,9 +324,24 @@ class OptionsWidget(QtWidgets.QWidget):
         del_device = QtWidgets.QPushButton("Remove Device")
         add_device.clicked.connect(self.new_device)
         del_device.clicked.connect(self.delete_device)
+        del_device.clicked.connect(del_device.hide)
         set_account.clicked.connect(self.change_profile)
         add_account.clicked.connect(self.new_profile)
         del_account.clicked.connect(self.delete_profile)
+        res_label = label(self, "**1080p is for PS4 Pro, PS5 only**", wrap=False)
+        hw_label = QtWidgets.QLineEdit(self)
+        hw_label.setText(self.get_decoder())
+        hw_label.setAlignment(Qt.AlignCenter)
+        hw_label.setReadOnly(True)
+        devices_label = label(
+            self,
+            "If your device is not showing up automatically, "
+            "try adding the IP Address below.",
+            wrap=True,
+        )
+        self.quality = QtWidgets.QComboBox(self)
+        self.quality.addItems([item.name for item in Quality])
+        self.quality.currentTextChanged.connect(self.change_quality)
         self.fps = QtWidgets.QComboBox(self)
         self.fps.addItems(["30", "60"])
         self.fps.currentTextChanged.connect(self.change_fps)
@@ -341,33 +357,38 @@ class OptionsWidget(QtWidgets.QWidget):
         self.accounts = QtWidgets.QTreeWidget()
         self.accounts.itemDoubleClicked.connect(self.change_profile)
         self.devices = QtWidgets.QTreeWidget()
+        self.devices.itemClicked.connect(del_device.show)
 
-        self.add(self.fps, 0, 1, label=label(self, "FPS:"))
-        self.add(self.fps_show, 0, 2)
-        self.add(self.resolution, 1, 1, label=label(self, "Resolution:"))
-        self.add(self.fullscreen, 1, 2)
-        res_label = label(self, "**1080p is for PS4 Pro only**", wrap=True)
-        self.layout.addWidget(res_label, 2, 0)
-        self.layout.addWidget(self.use_hw, 2, 2)
-        self.layout.addItem(spacer(), 3, 0)
-        self.add(set_account, 4, 0)
-        self.add(add_account, 4, 1)
-        self.add(del_account, 4, 2)
-        self.layout.addWidget(self.accounts, 5, 0, 3, 3)
-        self.layout.addItem(spacer(), 5, 3)
-        self.add(add_device, 4, 4)
-        self.add(del_device, 4, 5)
-        self.layout.addWidget(self.devices, 5, 4, 3, 2)
-        devices_label = label(
-            self,
-            "If your device is not showing up automatically, "
-            "try adding the IP Address below.",
-            wrap=True,
-        )
-        self.layout.addWidget(devices_label, 3, 4, 1, 2)
+        self.add(self.quality, 0, 1, label=label(self, "Quality:"))
+        self.add(self.fps, 1, 1, label=label(self, "FPS:"))
+        self.add(self.fps_show, 1, 2)
+        self.add(self.resolution, 2, 1, label=label(self, "Resolution:"))
+        self.add(self.fullscreen, 2, 2)
+        self.layout.addWidget(res_label, 3, 0, 1, 2)
+        self.add(hw_label, 4, 1, label=label(self, "Available Decoder:"))
+        self.layout.addWidget(self.use_hw, 4, 2)
+        self.layout.addWidget(devices_label, 4, 4, 1, 2)
+        self.layout.addItem(spacer(), 5, 0)
+        self.add(set_account, 6, 0)
+        self.add(add_account, 6, 1)
+        self.add(del_account, 6, 2)
+        self.add(add_device, 6, 4)
+        self.add(del_device, 6, 5)
+        self.layout.addWidget(self.accounts, 7, 0, 3, 3)
+        self.layout.addItem(spacer(), 7, 3)
+        self.layout.addWidget(self.devices, 7, 4, 3, 2)
+        del_device.hide()
+
+    def get_decoder(self):
+        decoder = AVReceiver.find_video_decoder(video_format="h264", use_hw=True)
+        decoder = decoder.replace("h264", "").replace("_", "")
+        if not decoder:
+            decoder = "CPU"
+        return decoder
 
     def set_options(self) -> bool:
         try:
+            self.quality.setCurrentText(str(self.options["quality"]))
             self.fps.setCurrentText(str(self.options["fps"]))
             self.fps_show.setChecked(self.options["show_fps"])
             self.use_hw.setChecked(self.options["use_hw"])
@@ -381,6 +402,7 @@ class OptionsWidget(QtWidgets.QWidget):
 
     def default_options(self) -> dict:
         options = {
+            "quality": "Default",
             "fps": 30,
             "show_fps": False,
             "resolution": "720p",
@@ -439,6 +461,10 @@ class OptionsWidget(QtWidgets.QWidget):
         if label is not None:
             self.layout.addWidget(label, row, col - 1, Qt.AlignLeft)
 
+    def change_quality(self, text):
+        self.options["quality"] = text
+        write_options(self.options)
+
     def change_fps(self, text):
         self.options["fps"] = int(text)
         write_options(self.options)
@@ -492,9 +518,10 @@ class OptionsWidget(QtWidgets.QWidget):
         self.set_devices()
 
     def delete_device(self):
-        item = self.devices.selectedItems()[0]
-        if not item:
+        items = self.devices.selectedItems()
+        if not items:
             return
+        item = items[0]
         host = item.text(0)
         self.options["devices"].remove(host)
         write_options(self.options)
