@@ -8,6 +8,7 @@ from struct import pack, pack_into, unpack_from
 
 from google.protobuf.message import DecodeError
 
+from .const import Quality
 from .takion_pb2 import *
 from .util import log_bytes, timeit
 
@@ -68,7 +69,7 @@ LAUNCH_SPEC = {
         'language': 'sp',
         'acceptButton': 'X',
         'connectedControllers': ['xinput', 'ds3', 'ds4'],
-        'yuvCoefficient': 'bt601',
+        'yuvCoefficient': 'bt709',  # Changed from bt601
         'videoEncoderProfile': 'hw4.1',
         'audioEncoderProfile': 'audio1'
     },
@@ -78,18 +79,28 @@ LAUNCH_SPEC = {
         'region': 'US',
         'languagesUsed': ['en', 'jp']
     },
-    'handshakeKey': None}
+    "adaptiveStreamMode": "resize",
+    "videoCodec": "avc",
+    "dynamicRange": "HDR",
+    'handshakeKey': None,
+}
 
 
 def get_launch_spec(
         handshake_key: bytes, resolution: dict, max_fps: int, rtt: int,
-        mtu_in: int) -> bytes:
+        mtu_in: int, quality: str) -> bytes:
     r = resolution
+    quality = quality.upper()
+    if quality == "DEFAULT":
+        bitrate = r['bitrate']
+    else:
+        bitrate = int(Quality[quality])
+    _LOGGER.info("Using bitrate: %s kbps", bitrate)
     launch_spec = LAUNCH_SPEC
     launch_spec['streamResolutions'][0]['resolution']['width'] = r['width']
     launch_spec['streamResolutions'][0]['resolution']['height'] = r['height']
     launch_spec['streamResolutions'][0]['maxFps'] = max_fps
-    launch_spec['network']['bwKbpsSent'] = r['bitrate']
+    launch_spec['network']['bwKbpsSent'] = bitrate
     launch_spec['network']['mtu'] = mtu_in
     launch_spec['network']['rtt'] = rtt
     launch_spec['handshakeKey'] = b64encode(handshake_key).decode()
